/*
 * Asterisk -- A telephony toolkit for Linux.
 *
 * App to send text
 * 
 * Copyright (C) 2004, Junghanns.NET GmbH
 *
 * Klaus-Peter Junghanns, <kpj@junghanns.net>
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License
 */
 
#include <asterisk/lock.h>
#include <asterisk/file.h>
#include <asterisk/logger.h>
#include <asterisk/channel.h>
#include <asterisk/pbx.h>
#include <asterisk/module.h>
#include <asterisk/translate.h>
#include <asterisk/options.h>
#include <string.h>
#include <stdlib.h>
#include <pthread.h>

static char *tdesc = "Send text Application";

static char *app = "SendText";

static char *synopsis = "Sends arbitrary text";

static char *descrip = 
"  SendText(text): Sends text on a channel.  Returns 0 on success"
"or -1 on a hangup.\n";

STANDARD_LOCAL_USER;

LOCAL_USER_DECL;

static int sendtext_exec(struct ast_channel *chan, void *data)
{
	int res = 0;
	struct localuser *u;
	char *text = data;
	struct ast_frame f;
	if (!text || !strlen(text)) {
		ast_log(LOG_WARNING, "SendText requires an argument (text)\n");
		return -1;
	}
	LOCAL_USER_ADD(u);
	res = ast_sendtext(chan, text);
	if (option_verbose > 2)
		ast_verbose(VERBOSE_PREFIX_3 "Sent text '%s' on %s result %d\n", text, chan->name, res);
			
	LOCAL_USER_REMOVE(u);
	return res;
}

int unload_module(void)
{
	STANDARD_HANGUP_LOCALUSERS;
	return ast_unregister_application(app);
}

int load_module(void)
{
	return ast_register_application(app, sendtext_exec, synopsis, descrip);
}

char *description(void)
{
	return tdesc;
}

int usecount(void)
{
	int res;
	STANDARD_USECOUNT(res);
	return res;
}

char *key()
{
	return ASTERISK_GPL_KEY;
}
